@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley with assistance from asn1ate v.0.6.0.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2019-2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -16,7 +17,11 @@ from pyasn1.type import namedtype
 from pyasn1.type import univ
 
 from pyasn1_alt_modules import rfc5280
-from pyasn1_alt_modules import rfc5751
+from pyasn1_alt_modules import opentypemap
+
+algorithmIdentifierMap = opentypemap.get('algorithmIdentifierMap')
+
+smimeCapabilityMap = opentypemap.get('smimeCapabilityMap')
 
 
 id_fortezzaConfidentialityAlgorithm = univ.ObjectIdentifier('2.16.840.1.101.2.1.1.4')
@@ -37,20 +42,20 @@ class Skipjack_Parm(univ.Sequence):
     )
 
 
-# Update the Algorithm Identifier map in rfc5280.py.
+# Update the Algorithm Identifier map
 
 _algorithmIdentifierMapUpdate = {
     id_fortezzaConfidentialityAlgorithm: Skipjack_Parm(),
     id_kEAKeyEncryptionAlgorithm: rfc5280.AlgorithmIdentifier(),
 }
 
-rfc5280.algorithmIdentifierMap.update(_algorithmIdentifierMapUpdate)
+algorithmIdentifierMap.update(_algorithmIdentifierMapUpdate)
 
 
-# Update the SMIMECapabilities Attribute map in rfc5751.py
+# Update the S/MIME Capability map
 
 _smimeCapabilityMapUpdate = {
     id_kEAKeyEncryptionAlgorithm: rfc5280.AlgorithmIdentifier(),
 }
 
-rfc5751.smimeCapabilityMap.update(_smimeCapabilityMapUpdate)
+smimeCapabilityMap.update(_smimeCapabilityMapUpdate)
