@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2019-2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -17,7 +18,12 @@ from pyasn1.type import namedtype
 from pyasn1.type import univ
 
 from pyasn1_alt_modules import rfc5280
+from pyasn1_alt_modules import opentypemap
 
+algorithmIdentifierMap = opentypemap.get('algorithmIdentifierMap')
+
+
+# Object Identifiers and Parameters for IDEA
 
 id_IDEA_CBC = univ.ObjectIdentifier('1.3.6.1.4.1.188.7.1.1.2')
 
@@ -32,11 +38,11 @@ class IDEA_CBCPar(univ.Sequence):
     )
 
 
-# Update the Algorithm Identifier map in rfc5280.py.
+# Update the Algorithm Identifiers Map and the SMIMECapability Map
 
 _algorithmIdentifierMapUpdate = {
     id_IDEA_CBC: IDEA_CBCPar(),
     id_alg_CMSIDEAwrap: univ.Null("")
 }
 
-rfc5280.algorithmIdentifierMap.update(_algorithmIdentifierMapUpdate)
+algorithmIdentifierMap.update(_algorithmIdentifierMapUpdate)
