@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -13,7 +14,9 @@
 #
 
 from pyasn1_alt_modules import rfc5751
-from pyasn1_alt_modules import rfc5280
+from pyasn1_alt_modules import opentypemap
+
+certificateExtensionsMap = opentypemap.get('certificateExtensionsMap')
 
 
 # Imports from RFC 5751
@@ -25,10 +28,10 @@ SMIMECapabilities = rfc5751.SMIMECapabilities
 SMIMECapability = rfc5751.SMIMECapability
 
 
-# Update the Certificate Extensions map in rfc5280.py.
+# Update the Certificate Extensions Map
 
 _certificateExtensionsMap = {
     smimeCapabilities: SMIMECapabilities(),
 }
 
-rfc5280.certificateExtensionsMap.update(_certificateExtensionsMap)
+certificateExtensionsMap.update(_certificateExtensionsMap)
