@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2019-2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -17,6 +18,9 @@ from pyasn1.type import constraint
 from pyasn1.type import univ
 
 from pyasn1_alt_modules import rfc5280
+from pyasn1_alt_modules import opentypemap
+
+otherNamesMap = opentypemap.get('otherNamesMap')
 
 MAX = float('inf')
 
@@ -39,11 +43,10 @@ srvName['type-id'] = id_on_dnsSRV
 srvName['value'] = SRVName()
 
 
-# Map of Other Name OIDs to Other Name is added to the
-# ones that are in rfc5280.py
+# Update the Other Names Map
 
-_anotherNameMapUpdate = {
+_otherNamesMapUpdate = {
     id_on_dnsSRV: SRVName(),
 }
 
-rfc5280.anotherNameMap.update(_anotherNameMapUpdate)
+otherNamesMap.update(_otherNamesMapUpdate)
