@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley with assistance from asn1ate v.0.6.0.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2019-2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -18,6 +19,9 @@ from pyasn1.type import univ
 
 from pyasn1_alt_modules import rfc5035
 from pyasn1_alt_modules import rfc5652
+from pyasn1_alt_modules import opentypemap
+
+cmsAttributesMap = opentypemap.get('cmsAttributesMap')
 
 
 class SignAttrsHash(univ.Sequence):
@@ -39,11 +43,10 @@ class MultipleSignatures(univ.Sequence):
 id_aa_multipleSignatures = univ.ObjectIdentifier('1.2.840.113549.1.9.16.2.51')
 
 
-# Map of Attribute Type OIDs to Attributes added to the
-# ones that are in rfc5652.py
+# Update the CMS Attribute Types Map
 
 _cmsAttributesMapUpdate = {
     id_aa_multipleSignatures: MultipleSignatures(),
 }
 
-rfc5652.cmsAttributesMap.update(_cmsAttributesMapUpdate)
+cmsAttributesMap.update(_cmsAttributesMapUpdate)
