@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley with assistance from asn1ate v.0.6.0.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2019-2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -16,8 +17,10 @@
 from pyasn1.type import constraint
 from pyasn1.type import univ
 
-from pyasn1_alt_modules import rfc5280
 from pyasn1_alt_modules import rfc5755
+from pyasn1_alt_modules import opentypemap
+
+certificateExtensionsMap = opentypemap.get('certificateExtensionsMap')
 
 MAX = float('inf')
 
@@ -34,11 +37,10 @@ class AuthorityClearanceConstraints(univ.SequenceOf):
     subtypeSpec=constraint.ValueSizeConstraint(1, MAX)
 
 
-# Map of Certificate Extension OIDs to Extensions added to the
-# ones that are in rfc5280.py
+# Update the Certificate Extensions Map
 
 _certificateExtensionsMapUpdate = {
     id_pe_clearanceConstraints: AuthorityClearanceConstraints(),
 }
 
-rfc5280.certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
+certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
