@@ -14,7 +14,9 @@
 from pyasn1.type import constraint
 from pyasn1.type import univ
 
-from pyasn1_alt_modules import rfc5652
+from pyasn1_alt_modules import opentypemap
+
+cmsAttributesMap = opentypemap.get('cmsAttributesMap')
 
 MAX = float('inf')
 
@@ -35,11 +37,10 @@ class BinarySigningTime(BinaryTime):
     pass
 
 
-# Map of Attribute Type OIDs to Attributes ia added to the
-# ones that are in rfc5652.py
+# Update the CMS Attribute Map
 
 _cmsAttributesMapUpdate = {
     id_aa_binarySigningTime: BinarySigningTime(),
 }
 
-rfc5652.cmsAttributesMap.update(_cmsAttributesMapUpdate)
+cmsAttributesMap.update(_cmsAttributesMapUpdate)
