@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -14,7 +15,9 @@
 
 from pyasn1.type import univ
 
-from pyasn1_alt_modules import rfc5280
+from pyasn1_alt_modules import opentypemap
+
+certificateExtensionsMap = opentypemap.get('certificateExtensionsMap')
 
 
 class SignedCertificateTimestampList(univ.OctetString):
@@ -33,7 +36,8 @@ id_kp_precertificateSigning = univ.ObjectIdentifier('1.3.6.1.4.1.11129.2.4.4')
 id_pkix_ocsp_SCT = univ.ObjectIdentifier('1.3.6.1.4.1.11129.2.4.5')
 
 
-# Update the Extension Map in rfc5280.py.
+# Update the Certificate Extension Map
+#
 # Note that rfc6960.py also uses this same map for OCSP extensions.
 # The id_ce_criticalPoison OID is not automatically added to the map
 # because normal relying parties are supposed to reject certificates
@@ -45,4 +49,4 @@ _certificateExtensionsMapUpdate = {
     id_pkix_ocsp_SCT: SignedCertificateTimestampList(),
 }
 
-rfc5280.certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
+certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
