@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2019-2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -16,7 +17,9 @@
 from pyasn1.type import univ
 
 from pyasn1_alt_modules import rfc3779
-from pyasn1_alt_modules import rfc5280
+from pyasn1_alt_modules import opentypemap
+
+certificateExtensionsMap = opentypemap.get('certificateExtensionsMap')
 
 
 # IP Address Delegation Extension V2
@@ -33,12 +36,11 @@ id_pe_autonomousSysIds_v2 = univ.ObjectIdentifier('1.3.6.1.5.5.7.1.29')
 ASIdentifiers = rfc3779.ASIdentifiers
 
 
-# Map of Certificate Extension OIDs to Extensions is added to the
-# ones that are in rfc5280.py
+# Update the Certificate Extensions Map
 
 _certificateExtensionsMapUpdate = {
     id_pe_ipAddrBlocks_v2: IPAddrBlocks(),
     id_pe_autonomousSysIds_v2: ASIdentifiers(),
 }
 
-rfc5280.certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
+certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
