@@ -2,6 +2,7 @@
 # This file is part of pyasn1-alt-modules software.
 #
 # Created by Russ Housley.
+# Modified by Russ Housley to include the opentypemap manager.
 #
 # Copyright (c) 2021, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
@@ -15,7 +16,9 @@
 from pyasn1.type import char
 from pyasn1.type import univ
 
-from pyasn1_alt_modules import rfc5280
+from pyasn1_alt_modules import opentypemap
+
+certificateExtensionsMap = opentypemap.get('certificateExtensionsMap')
 
 
 id_pe = univ.ObjectIdentifier((1, 3, 6, 1, 5, 5, 7, 1))
@@ -27,11 +30,10 @@ class MASAURLSyntax(char.IA5String):
     pass
 
 
-# Map of Certificate Extension OIDs to Extensions added to the
-# ones that are in rfc5280.py
+# Update the Certificate Extensions Map
 
 _certificateExtensionsMapUpdate = {
     id_pe_masa_url: MASAURLSyntax(),	
 }
 
-rfc5280.certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
+certificateExtensionsMap.update(_certificateExtensionsMapUpdate)
